# MLM25: MaveDB Amino Acid Substitution Prediction
## Summary
Understanding the functional consequences of genetic variants is a cornerstone of modern genomics. Multiplexed Assays of Variant Effect (MAVEs) provide high-throughput measurements of how thousands of variants impact gene function, and MaveDB is a growing repository of these datasets, but it is still expensive and time-consuming to experimentally test every variant. In this challenge, your task is to develop a machine learning model that can predict the functional outcomes of amino acid substitutions.

# Sources/Citations

[MaveDB](https://mavedb.org/)
> Rubin, A.F., Stone, J., Bianchi, A.H. et al. MaveDB 2024: a curated community database with over seven million variant effects from multiplexed functional assays. Genome Biol 26, 13 (2025). https://doi.org/10.1186/s13059-025-03476-y

[ESM C](https://www.evolutionaryscale.ai/blog/esm-cambrian)
> ESM Team. "ESM Cambrian: Revealing the mysteries of proteins with unsupervised learning." EvolutionaryScale, 2024, https://evolutionaryscale.ai/blog/esm-cambrian.